Minor name change (move the ObjC prefix to a more appropriate place).


git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@65695 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/Driver/PrintParserCallbacks.cpp b/Driver/PrintParserCallbacks.cpp
index e3850ba..bc28db5 100644
--- a/Driver/PrintParserCallbacks.cpp
+++ b/Driver/PrintParserCallbacks.cpp
@@ -134,7 +134,7 @@
       return 0;
     }
 
-    virtual void ObjCActOnStartOfMethodDef(Scope *FnBodyScope, DeclTy *D) {
+    virtual void ActOnStartOfObjCMethodDef(Scope *FnBodyScope, DeclTy *D) {
       llvm::cout << __FUNCTION__ << "\n";
     }
   
diff --git a/include/clang/Parse/Action.h b/include/clang/Parse/Action.h
index a7f2e76..9b4e980 100644
--- a/include/clang/Parse/Action.h
+++ b/include/clang/Parse/Action.h
@@ -262,7 +262,7 @@
     return D;
   }
 
-  virtual void ObjCActOnStartOfMethodDef(Scope *FnBodyScope, DeclTy *D) {
+  virtual void ActOnStartOfObjCMethodDef(Scope *FnBodyScope, DeclTy *D) {
     return;
   }
 
diff --git a/lib/Parse/ParseObjc.cpp b/lib/Parse/ParseObjc.cpp
index 4ddddb3..3aa525b 100644
--- a/lib/Parse/ParseObjc.cpp
+++ b/lib/Parse/ParseObjc.cpp
@@ -1377,7 +1377,7 @@
   
   // Tell the actions module that we have entered a method definition with the
   // specified Declarator for the method.
-  Actions.ObjCActOnStartOfMethodDef(CurScope, MDecl);
+  Actions.ActOnStartOfObjCMethodDef(CurScope, MDecl);
 
   OwningStmtResult FnBody(ParseCompoundStatementBody());
 
diff --git a/lib/Sema/Sema.h b/lib/Sema/Sema.h
index 1b6d6c1..ead93cb 100644
--- a/lib/Sema/Sema.h
+++ b/lib/Sema/Sema.h
@@ -295,7 +295,7 @@
   virtual void ActOnFinishKNRParamDeclarations(Scope *S, Declarator &D);
   virtual DeclTy *ActOnStartOfFunctionDef(Scope *S, Declarator &D);
   virtual DeclTy *ActOnStartOfFunctionDef(Scope *S, DeclTy *D);
-  virtual void ObjCActOnStartOfMethodDef(Scope *S, DeclTy *D);
+  virtual void ActOnStartOfObjCMethodDef(Scope *S, DeclTy *D);
 
   virtual DeclTy *ActOnFinishFunctionBody(DeclTy *Decl, StmtArg Body);
   virtual DeclTy *ActOnFileScopeAsmDecl(SourceLocation Loc, ExprArg expr);
diff --git a/lib/Sema/SemaDeclObjC.cpp b/lib/Sema/SemaDeclObjC.cpp
index cc86786..654891d 100644
--- a/lib/Sema/SemaDeclObjC.cpp
+++ b/lib/Sema/SemaDeclObjC.cpp
@@ -17,9 +17,9 @@
 #include "clang/Parse/DeclSpec.h"
 using namespace clang;
 
 /// ObjCActOnStartOfMethodDef - This routine sets up parameters; invisible
 /// and user declared, in the method definition's AST.
-void Sema::ObjCActOnStartOfMethodDef(Scope *FnBodyScope, DeclTy *D) {
+void Sema::ActOnStartOfObjCMethodDef(Scope *FnBodyScope, DeclTy *D) {
   assert(getCurMethodDecl() == 0 && "Method parsing confused");
   ObjCMethodDecl *MDecl = dyn_cast_or_null<ObjCMethodDecl>((Decl *)D);
@@ -17,9 +17,9 @@
 using namespace clang;
 
-/// ObjCActOnStartOfMethodDef - This routine sets up parameters; invisible
+/// ActOnStartOfObjCMethodDef - This routine sets up parameters; invisible
 /// and user declared, in the method definition's AST.